@@ -104,11 +104,11 @@ static inline unsigned char ScaleQuantumToChar(const Quantum quantum)
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
   return((unsigned char) quantum);
 #else
-  if ((IsNaN(quantum) != 0) || (quantum <= 0.0))
+  if ((IsNaN(quantum) != 0) || (quantum <= 0.0f))
     return(0);
   if (quantum >= 255.0)
     return(255);
-  return((unsigned char) (quantum+0.5));
+  return((unsigned char) (quantum+0.5f));
 #endif
 }
 #elif (MAGICKCORE_QUANTUM_DEPTH == 16)
@@ -117,11 +117,11 @@ static inline unsigned char ScaleQuantumToChar(const Quantum quantum)
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
   return((unsigned char) (((quantum+128UL)-((quantum+128UL) >> 8)) >> 8));
 #else
-  if ((IsNaN(quantum) != 0) || (quantum <= 0.0))
+  if ((IsNaN(quantum) != 0) || (quantum <= 0.0f))
     return(0);
-  if ((quantum/257.0) >= 255.0)
+  if ((quantum/257.0f) >= 255.0f)
     return(255);
-  return((unsigned char) (quantum/257.0+0.5));
+  return((unsigned char) (quantum/257.0f+0.5f));
 #endif
 }
 #elif (MAGICKCORE_QUANTUM_DEPTH == 32)
