@@ -18,11 +18,16 @@
 #ifndef MAGICKCORE_STUDIO_H
 #define MAGICKCORE_STUDIO_H
 
+#if defined(_OPENMP) && ((_OPENMP >= 200203) || defined(__OPENCC__))
+#  include <omp.h>
+#  define MAGICKCORE_OPENMP_SUPPORT  1
+#endif
+
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-#if defined(WIN32) || defined(WIN64)
+#if defined(WIN32) || defined(WIN64) || defined(_WIN32_WINNT)
 #  define MAGICKCORE_WINDOWS_SUPPORT
 #else
 #  define MAGICKCORE_POSIX_SUPPORT
@@ -155,11 +160,6 @@ extern "C" {
 #  define MAGICKCORE_OPENCL_SUPPORT  1
 #endif
 
-#if defined(_OPENMP) && ((_OPENMP >= 200203) || defined(__OPENCC__))
-#  include <omp.h>
-#  define MAGICKCORE_OPENMP_SUPPORT  1
-#endif
-
 #if defined(MAGICKCORE_HAVE_PREAD) && defined(MAGICKCORE_HAVE_DECL_PREAD) && !MAGICKCORE_HAVE_DECL_PREAD
 ssize_t pread(int,void *,size_t,off_t);
 #endif
@@ -288,7 +288,7 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
 #  define Exit  exit
 #  define IsBasenameSeparator(c) \
   (((c) == ']') || ((c) == ':') || ((c) == '/') ? MagickTrue : MagickFalse)
-#  define MAGICKCORE_LIBRARY_PATH  "sys$login:"
+#  define MAGICKCORE_LIBRARY_ABSOLUTE_PATH  "sys$login:"
 #  define MAGICKCORE_SHARE_PATH  "sys$login:"
 #  define X11_PREFERENCES_PATH  "decw$user_defaults:"
 #  define ProcessPendingEvents(text)
@@ -313,7 +313,7 @@ extern int vsnprintf(char *,size_t,const char *,va_list);
 #  define DirectoryListSeparator  ';'
 #  define EditorOptions ""
 #  define IsBasenameSeparator(c)  ((c) == ':' ? MagickTrue : MagickFalse)
-#  define MAGICKCORE_LIBRARY_PATH  ""
+#  define MAGICKCORE_LIBRARY_ABSOLUTE_PATH  ""
 #  define MAGICKCORE_SHARE_PATH  ""
 #  define X11_PREFERENCES_PATH  "~/."
 #  if defined(DISABLE_SIOUX)
