@@ -30,17 +30,17 @@ extern "C" {
 #define MagickLibVersion  0x69D
 #define MagickLibVersionText  "6.9.13"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-16"
+#define MagickLibAddendum  "-26"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
-#define MagickPlatform  "aarch64"
+#define MagickPlatform  "x86_64"
 #define MagickppLibVersionText  "6.9.13"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-16"
+#define MagickppLibAddendum  "-26"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickGitRevision  "18467"
-#define MagickReleaseDate  "2024-09-01"
+#define MagickGitRevision  "18837"
+#define MagickReleaseDate  "2025-07-13"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
